%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% @author   Michael Fang
% @version  V1.0.0
% @data     08-Oct-2016
% @param    arm: specifies the arm (1 - YI arm; 2 - YQ arm; 3 - YP arm; 
%           4 - XI arm; 5 - XQ arm; 6 - XP arm;)
%           bias: current bias voltage of specified arm
% @brief    ReadBias.m will return current bias voltage of specified arm
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [bias] = ReadBias(arm)
global s;
if(s.BytesAvailable ~= 0)
    fread(s,s.BytesAvailable);
end
byteID=102;
byteData=[arm 0 0 0 0 0];
fwrite(s,[byteID byteData]);
dataRec = fread(s,9);
returnedByteID = dataRec(1,1);
if(returnedByteID ~= byteID)
    status = 102;
    disp('Unknown Error. Please try again')
    return;
end
status = dataRec(6,1);
answerHex = strcat(dec2hex(dataRec(5,1),2),dec2hex(dataRec(4,1),2),dec2hex(dataRec(3,1),2),dec2hex(dataRec(2,1),2));
convertedData = typecast(uint32(hex2dec(answerHex)),'single');
bias = convertedData;
if(status==119)
    disp('This function cannot be used now, please try later')
end
end